import { defineConfig } from "tsup";

export default defineConfig((o) => {
  return {
    ...o,
    entry: ["src/index.ts"],
    format: ["esm", "cjs"], // Build for commonJS and ESmodules
    dts: true, // Generate declaration file (.d.ts)
    splitting: true,
    outDir: o.format === "cjs" ? "dist/cjs" : "dist",
    sourcemap: true,
    clean: true,

    treeshake: true, // Remove unused dependencies
    skipNodeModulesBundle: false, // Skips building dependencies for node modules

    bundle: true, // Bundle all dependencies into one file
    // minify: !options.watch,

    cjsInterop: true, // Enable CJS interop, so we can use CJS imports in ESM
    esbuildPlugins: [
      {
        name: "cjs-interop",
        setup(build) {
          build.onResolve({ filter: /\.cjs$/ }, (args) => ({
            path: args.path,
            namespace: "cjs-interop",
          }));
        },
      },
    ],
  };
});
